==> cordova-sqlite-react-1.1.7.tgz: package/stringSQL/generateDelete.ts <==
import { DeleteWhere } from '../@types/commonType';



export const generateSQLDelete = (nameTable:string, {where, whereKey, stringWhere, ignoreWhere, condition}:DeleteWhere):{newSQLDelete: string} => {
  /*
    generateSQLDelete('Test', {whereKey: {name: ['Вася', "Петя"], age: [17,20]}})
    'DELETE FROM Test WHERE name = "Вася" OR name = "Петя", age = "17" OR age = "20"'
  */
 
  let total = {
    defaultSqlStr: `DELETE FROM ${nameTable}`
  }
  total.defaultSqlStr = total.defaultSqlStr.replace(/,$/ig, ` ${stringWhere ? stringWhere : 'WHERE'}`);

  if(stringWhere){
    total.defaultSqlStr += ` ${stringWhere}`;
  }else if(whereKey && Object.keys(whereKey).length){
    whereTotalHelpers({ob: whereKey, total , condition, ignoreWhere}, ignoreForWhereKey)
    // let entries = Object.entries(whereKey);
  

    // for(let [key, value] of entries){
    //   for(let i = 0; i < value.length; i++){
    //     let ignoreStatus = false;


    //     if(ignoreWhere){

    //       let findItemInx = ignoreWhere[key].findIndex((ignK) => ignK === value[i]);
    //       if(~findItemInx){
    //         ignoreStatus = true;
    //         ignoreWhere[key].splice(findItemInx, 1);
    //       }
    //     }
    //     defaultSqlStr += (` ${key} ${ignoreStatus ? '!=' : '='} "${value[i]}" ${condition ? condition : 'OR'}`)
    //   }
    //   defaultSqlStr = defaultSqlStr.replace(/(\sAND|\sOR)$/ig, ``);
    //   defaultSqlStr += ','
    
    // }

    // defaultSqlStr = defaultSqlStr.replace(/,$/ig, ``);




  }else if(where && Object.keys(where).length){
    
      for(let [key, value] of Object.entries(where)){
        total.defaultSqlStr += (` ${key}="${value}" ${condition ? condition : 'OR'}`);
      }

      total.defaultSqlStr = total.defaultSqlStr.replace(/(\sAND|\sOR)$/ig, ``);
      
  }else{
    console.dir('Не передано ни одно из свойств where, whereKey, stringWhere');
  }
  
  if(ignoreWhere && Object.keys(ignoreWhere).length){
    whereTotalHelpers({ob: ignoreWhere, total, condition, ignoreWhere}, ignoreConcatKey)


  }
  console.dir(total.defaultSqlStr);
  return {
    newSQLDelete: total.defaultSqlStr
  };
  
}


const ignoreForWhereKey = ({total, key, value, condition, ignoreWhere}) => {
  let ignoreStatus = false;


  if(ignoreWhere){

    let findItemInx = ignoreWhere[key].findIndex((ignK) => ignK === value);
    if(~findItemInx){
      ignoreStatus = true;
      ignoreWhere[key].splice(findItemInx, 1);
    }
  }

  total.defaultSqlStr += (` ${key} ${ignoreStatus ? '!=' : '='} "${value}" ${condition ? condition : 'OR'}`)
}

const ignoreConcatKey = ({total, key, value, condition, ignoreStatus}) => {
  total.defaultSqlStr += (` ${condition ? condition : 'OR'} ${key} != "${value}" ${condition ? condition : 'OR'}`)
}


const whereTotalHelpers = ({ob, total, condition, ignoreWhere}, cb?: (...param:any) => void) => {

  let entries = Object.entries(ob) as any;
  
  for(let [key, value] of entries){
    for(let i = 0; i < value.length; i++){

      cb && cb({total, key, value: value[i], condition, ignoreWhere});

    }
    total.defaultSqlStr = total.defaultSqlStr.replace(/(\sAND|\sOR)$/ig, ``);
    total.defaultSqlStr += ','
  }

  total.defaultSqlStr = total.defaultSqlStr.replace(/,$/ig, ``);
}






// generateSQLDelete('Test', {whereKey: {key: ['Jon', 'Brain']}, ignoreWhere: {key: []}})







// const name = ({ignoreWhereKey}) => {
//   let ignoreStatus = false;

//   if(ignoreWhere){

//     let findItemInx = ignoreWhere[key].findIndex((ignK) => ignK === value[i]);
//     if(~findItemInx){
//       ignoreStatus = true;
//       ignoreWhere[key].splice(findItemInx, 1);
//     }
//   }
// }

==> cordova-sqlite-react-1.1.8.tgz: package/stringSQL/generateDelete.ts <==
import { DeleteWhere } from '../@types/commonType';



export const generateSQLDelete = (nameTable:string, {where, whereKey, stringWhere, ignoreWhere, condition}:DeleteWhere):{newSQLDelete: string} => {
  /*
    generateSQLDelete('Test', {whereKey: {name: ['Вася', "Петя"], age: [17,20]}})
    'DELETE FROM Test WHERE name = "Вася" OR name = "Петя", age = "17" OR age = "20"'
  */
 
  let checkOptions = 0;
  let total = {
    defaultSqlStr: `DELETE FROM ${nameTable} ${stringWhere ? stringWhere : 'WHERE'}`
  }
  // total.defaultSqlStr = total.defaultSqlStr.replace(/,$/ig, ` ${stringWhere ? stringWhere : 'WHERE'}`);

  if(stringWhere){
    checkOptions++;
    total.defaultSqlStr += ` ${stringWhere}`;
  }else if(whereKey && Object.keys(whereKey).length){
    whereTotalHelpers({ob: whereKey, total , condition, ignoreWhere, checkOptions}, ignoreForWhereKey)

  }else if(where && Object.keys(where).length){
      checkOptions++;

      for(let [key, value] of Object.entries(where)){
        total.defaultSqlStr += (` ${key}="${value}" ${condition ? condition : 'OR'}`);
      }

      total.defaultSqlStr = total.defaultSqlStr.replace(/(\sAND|\sOR)$/ig, ``);
      
  }
  
  if(ignoreWhere && Object.keys(ignoreWhere).length){
    checkOptions++;
    whereTotalHelpers({ob: ignoreWhere, total, condition, ignoreWhere, checkOptions}, ignoreConcatKey)
  }
  if(checkOptions === 0){
    console.dir(`Доп параметры не переданы, будут удалены все ключи в таблице ${nameTable}`);
    total.defaultSqlStr = total.defaultSqlStr.replace(/\sWHERE$/ig, ``);
  }
  total.defaultSqlStr = total.defaultSqlStr.replace(/(\sAND|\sOR)$/ig, ``);
  console.dir(total.defaultSqlStr);
  return {
    newSQLDelete: total.defaultSqlStr
  };
  
}


const ignoreForWhereKey = ({total, key, value, condition, ignoreWhere, }) => {
  let ignoreStatus = false;


  if(ignoreWhere){

    let findItemInx = ignoreWhere[key].findIndex((ignK) => ignK === value);
    if(~findItemInx){
      ignoreStatus = true;
      ignoreWhere[key].splice(findItemInx, 1);
    }
  }

  total.defaultSqlStr += (` ${key} ${ignoreStatus ? '!=' : '='} "${value}" ${condition ? condition : 'OR'}`)
}

const ignoreConcatKey = ({total, key, value, condition, checkOptions}) => {



  total.defaultSqlStr += (`${checkOptions === 1 ? '' : condition ? condition : 'OR'} ${key} != "${value}" ${condition ? condition : 'OR'}`)
}


const whereTotalHelpers = ({ob, total, condition, ignoreWhere, checkOptions}, cb?: (...param:any) => void) => {

  let entries = Object.entries(ob) as any;
  
  for(let [key, value] of entries){
    for(let i = 0; i < value.length; i++){

      cb && cb({total, key, value: value[i], condition, ignoreWhere, checkOptions});

    }
    !ignoreWhere && (total.defaultSqlStr = total.defaultSqlStr.replace(/(\sAND|\sOR)$/ig, ``));
    total.defaultSqlStr += ','
  }
  
  total.defaultSqlStr = total.defaultSqlStr.replace(/,$/ig, ``);
}










    // let entries = Object.entries(whereKey);
  
    // for(let [key, value] of entries){
    //   for(let i = 0; i < value.length; i++){
    //     let ignoreStatus = false;


    //     if(ignoreWhere){

    //       let findItemInx = ignoreWhere[key].findIndex((ignK) => ignK === value[i]);
    //       if(~findItemInx){
    //         ignoreStatus = true;
    //         ignoreWhere[key].splice(findItemInx, 1);
    //       }
    //     }
    //     defaultSqlStr += (` ${key} ${ignoreStatus ? '!=' : '='} "${value[i]}" ${condition ? condition : 'OR'}`)
    //   }
    //   defaultSqlStr = defaultSqlStr.replace(/(\sAND|\sOR)$/ig, ``);
    //   defaultSqlStr += ','
    
    // }

    // defaultSqlStr = defaultSqlStr.replace(/,$/ig, ``);


// const name = ({ignoreWhereKey}) => {
//   let ignoreStatus = false;

//   if(ignoreWhere){

//     let findItemInx = ignoreWhere[key].findIndex((ignK) => ignK === value[i]);
//     if(~findItemInx){
//       ignoreStatus = true;
//       ignoreWhere[key].splice(findItemInx, 1);
//     }
//   }
// }
